/*
Projection au doigt
-------------------

On va déterminer le vecteur de projection du mouvement 
effectué au doigt / à la souris.

On va appliquer ce vecteur à la vitesse d'un Sprite p5play
(car p5play intègre déjà un moteur physique basique dans ses sprites)

L'essentiel de la projection se passe tout en bas du code !
mousePressed() / mouseReleased()

*/

var g; // g c'est LE fantôme qu'on va contrôler

function setup(){ 

	createCanvas(windowWidth, windowHeight);

	// on ajoute un fantôme = un Sprite p5play
	g = createSprite(width/2, height/2, 64, 92); // x, y, L, H
  	g.addAnimation("vole", "img/fighter1.png", "img/fighter3.png", "img/fighter2.png", "img/fighter3.png");
	g.changeAnimation("vole");

	// il commence avec une vitesse aléatoire
	g.velocity.x = random(-1, 1);
	g.velocity.y = random(-1, 1);

}
function draw(){
	background(0); // nettoyer l'affichage à chaque cycle

	// on empêche le fantôme de sortir de l'écran
	if(g.position.x<0){
		g.velocity.x = Math.abs(g.velocity.x); // vitesse positive
	} else if(g.position.x>width){
		g.velocity.x = -Math.abs(g.velocity.x); // vitesse négative
	}
	if(g.position.y<0){
		g.velocity.y = Math.abs(g.velocity.y); // vitesse positive
	} else if(g.position.y>height){
		g.velocity.y = -Math.abs(g.velocity.y); // vitesse négative
	}

	// !!! imortant !!! rafraichir l'affichage de tous les Sprites p5play
	drawSprites();

	// Optionnel : dessiner le vecteur de projection à l'écran !
	// (et il suffit de virer ces lignes pour ne plus dessiner le vecteur)
	if(start.x && start.y){ // si la position de départ du doigt est définie...
		noFill();
		stroke(255);
		ellipse(start.x, start.y, 30, 30); // cercle au point de départ
		line(start.x, start.y, mouseX, mouseY); // ligne jusqu'à la position actuelle du doigt
	}

	// afficher le mode d'emploi !
	fill(255);
	noStroke();
	rect(20, 10, 280, 36);
	noFill();
	stroke(0);
	text("// Cliquez-glissez avec le doigt ou la souris !", 30, 30);
}

/*
// Projection !
on récupère l'endroit où on touche l'écran, et l'endroit où on le relâche.
le "vecteur" de projection va de l'un à l'autre, et ça nous donne
la direction et la vitesse de projection du fantôme...
*/

var start = {}; // pour stocker le point de départ du doigt jusqu'à ce qu'on relâche
function mousePressed(){ // qd on touche l'écran (ou qu'on clique)
	start = {
		x: mouseX,
		y: mouseY
	};
}
function mouseReleased(){ // qd on relâche l'écran / le bouton de la souris
	var distX = mouseX - start.x;
	var distY = mouseY - start.y;

	// problème : ce sont des nombres beaucoup trop grands pour une vitesse,
	// ça va projecter le fantôme à la vitesse de la lumière !
	// la direction est bonne, mais il faut ralentir la projection : 
	// une division fait très bien l'affaire !

	g.velocity.x = distX/50;
	g.velocity.y = distY/50;
	// moins que 50 ça accélère la projection
	// plus que 50 ça ralentit la projection

	start = {}; // on ré-initialise la variable start
	// pour arrêter le dessin du vecteur à l'écran
	// le dessin du vecteur ça se passe dans draw()...
}